/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2004-2010 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Andreas Mayer <andreas.mayer@open-xchange.com>
 * @author Stefan Preuss <stefan.preuss@open-xchange.com>
 * 
 */

register("OX_Login",loadMiniCalendar);

var oMiniCalendar;
var b3xViewLoaded;
var calendarMiniJson = new JSON();

function loadMiniCalendar() {
	showNode("calendarMini");
	function updateMiniCalData() {
		oMiniCalendar.update();	
	}	
	register("OX_Refresh_Mini_Calendar",updateMiniCalData);
	register("OX_Refresh",updateMiniCalData);
	oMiniCalendar = new cAnimMiniCalendar(fn_minicalendar_action,null);
	b3xViewLoaded = false;
}

function fn_minicalendar_action() {	
	oMiniCalendar.setSelected(this.id);
	activeDay=oMiniCalendar.selectedDate;
	activeMonth=oMiniCalendar.selectedMonth;
	activeYear=oMiniCalendar.selectedYear;
	
	// notify
	triggerEvent("OX_Mini_Calendar_Date_Picked", activeYear, activeMonth, activeDay);

	if(currentpath[0] == "calendar") {
		if (currentpath[1] != "team" && currentpath[2] == "month") {
			// this routine is not required in team view; might do too much in other views anyway...
	        loadMonthView();
		} 	
		triggerEvent("OX_Switch_View",currentpath.join("/"));			
	} else if (configContainsKey("folder.calendar")) {
		setActiveFolder(configGetKey("folder.calendar"), function () {
			triggerEvent("OX_Switch_View","calendar/calendar/day"); 
		});
	}
}

fileloaded();
